BasicPhraseBuilder

Struct BasicPhraseBuilder 

pub struct BasicPhraseBuilder { /* private fields */ }
A passphrase builder with as constant word separator.

This is a basic passphrase builder that uses a given set of words to build a full passphrase. This builder uses a single fixed separator, that is used as glue between all the passphrase words.

Implementations

Source

impl BasicPhraseBuilder

pub fn new(separator: String) -> Self