pub trait WordSetProvider:
HasEntropy
+ Debug
+ Send
+ Sync {
// Required method
fn words(&self) -> Vec<String>;
}Expand description
Something that provides sets of random words.
A component that provides functionallity to source a random set of passphrase words. On sourcing, an ordered list of random passphrase words is returned that will be used in the password.
This differs from WordProvider as this provides a set of words instead of a
single word. It should be fairly easy to implement this trait on types that have the
WordProvider implemented.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".